use strict;
use warnings;
use Test::More;

use_ok 'PkgConfig::LibPkgConf';
use_ok 'PkgConfig::LibPkgConf::Client';
use_ok 'PkgConfig::LibPkgConf::Package';
use_ok 'PkgConfig::LibPkgConf::Util';
use_ok 'PkgConfig::LibPkgConf::Fragment';

done_testing;
